from Tamako import Tamako
from plot_func import plot_func
from func_solv import func_solv
from fittedLinear import fittedLinear
from determinant_eigen import determinant_eigen
from independent_dependent import independent_dependent
from bivariate import bivariate

__title__ = "Tamako.py"
__version__ = "0.7"
__author__ = "BearTS"
__license__ = "MIT"
